@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '0.66';
+  $CPAN::Perl::Releases::VERSION = '0.68';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -287,6 +287,10 @@ our $data =
     "tar.bz2" => "T/TO/TONYC/perl-5.17.2.tar.bz2",
     "tar.gz" => "T/TO/TONYC/perl-5.17.2.tar.gz",
   },
+  "5.17.3" => {
+    "tar.bz2" => "S/SH/SHAY/perl-5.17.3.tar.bz2",
+    "tar.gz" => "S/SH/SHAY/perl-5.17.3.tar.gz",
+  },
   "5.6.0" => {
     "tar.gz" => "G/GS/GSAR/perl-5.6.0.tar.gz",
   },
@@ -395,7 +399,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.66
+version 0.68
 
 =head1 SYNOPSIS
 
